# "DISM" Module in Python
## Easily use Microsoft's DISM Command-Line Interface in Python.
This Python module provides an interface for interacting with the Deployment Imaging Service and Management Tool (DISM). It allows you to manage and service Windows images, drivers, packages, and system health using DISM commands through Python scripts.

## Features
 - Capture and Apply Windows images
 - Mount and unmount Windows images
 - Get infos about Windows images
 - Add and remove drivers and packages
 - Enable and disable Windows features
 - Check, scan and restore system health

## Installation

To install this module, you can use pip:

```sh
pip install dism
```

## Requirements
 - Python 3.0 or higher
 - Windows operating system with DISM available

## Usage & Command Reference
See in [wiki](https://github.com/samuellouf/DISM).

## License
This project is licensed under the MIT License. See the LICENSE file for details.

## Contributing
Contributions are welcome! Please submit a pull request or open an issue to discuss any changes.